@@ -16,9 +16,9 @@ txt2man -d "$T2M_DATE" -t $T2M_NAME -r $T2M_NAME-$T2M_VERSION -s $T2M_LEVEL -v "
 #--------------------------------------------------------
 
 # Put here all data for your first manpage (in T2M lines)
-T2M_DATE="02 Aug 2020"
+T2M_DATE="03 Mar 2022"
 T2M_NAME=packetsender
-T2M_VERSION=7.0.5
+T2M_VERSION=8.0.9
 T2M_LEVEL=1
 T2M_DESC="Network utility for sending and receiving TCP, UDP, SSL packets"
 create-man
